@@ -54,8 +54,8 @@ class Template:
         return "/AS"
 
     @property
-    def radio_button_group_key(self) -> str:
-        """Used for extracting grouped radio button keys for pdfrw parsed PDF form."""
+    def parent_key(self) -> str:
+        """Used for extracting parent elements for pdfrw parsed PDF form."""
 
         return "/Parent"
 
@@ -65,6 +65,18 @@ class Template:
 
         return "/Ff"
 
+    @property
+    def text_field_identifier(self) -> str:
+        """Used for identifying if an element is a text field."""
+
+        return "/Tx"
+
+    @property
+    def selectable_identifier(self) -> str:
+        """Used for identifying if an element is a checkbox or radio button."""
+
+        return "/Btn"
+
 
 class Merge:
     """Contains constants for merging PDFs."""
