@@ -5,7 +5,6 @@ from enum import Enum
 from typing import Union
 
 from ..core.font import Font as FontCore
-from ..core.image import Image as ImageCore
 from .exceptions.element import (InvalidElementNameError,
                                  InvalidElementTypeError,
                                  InvalidElementValueError,
@@ -19,7 +18,6 @@ class ElementType(Enum):
 
     text = "text"
     checkbox = "checkbox"
-    image = "image"
     radio = "radio"
 
 
@@ -30,7 +28,7 @@ class Element:
         self,
         element_name: str,
         element_type: "ElementType",
-        element_value: Union[str, bool, bytes, int] = None,
+        element_value: Union[str, bool, int] = None,
     ) -> None:
         """Constructs all attributes for the Element object."""
 
@@ -78,13 +76,6 @@ class Element:
             if self.value is not None and not isinstance(self.value, bool):
                 raise InvalidElementValueError
 
-        if self._type == ElementType.image:
-            if self.value is not None:
-                if not isinstance(self.value, bytes):
-                    raise InvalidElementValueError
-                if not ImageCore().is_image(self.value):
-                    raise InvalidElementValueError
-
         if self._type == ElementType.radio:
             if self.value is not None and not isinstance(self.value, int):
                 raise InvalidElementValueError
