@@ -26,17 +26,34 @@ class Template:
             raise InvalidTemplateError
 
     @staticmethod
-    def build_elements(pdf_stream: bytes) -> Dict[str, "Element"]:
+    def build_elements(pdf_stream: bytes, sejda: bool = False) -> Dict[str, "Element"]:
         """Builds an element dict given a PDF form stream."""
 
         results = {}
 
-        for element in TemplateCore().iterate_elements(pdf_stream):
-            key = TemplateCore().get_element_key(element)
+        for element in TemplateCore().iterate_elements(pdf_stream, sejda):
+            key = TemplateCore().get_element_key(element, sejda)
 
             results[key] = Element(
                 element_name=key,
-                element_type=TemplateCore().get_element_type(element),
+                element_type=TemplateCore().get_element_type(element, sejda),
             )
 
         return results
+
+    @staticmethod
+    def build_elements_v2(pdf_stream: bytes) -> Dict[str, "Element"]:
+        """Builds an element dict given a PDF form stream."""
+
+        results = {}
+
+        for elements in TemplateCore().get_elements_by_page_v2(pdf_stream).values():
+            for element in elements:
+                key = TemplateCore().get_element_key_v2(element)
+
+                results[key] = Element(
+                    element_name=key,
+                    element_type=TemplateCore().get_element_type_v2(element),
+                )
+
+        return results
